==> shardingsphere-data-pipeline-api-5.3.2-sources.jar: org/apache/shardingsphere/data/pipeline/api/metadata/SchemaTableName.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.data.pipeline.api.metadata;

import lombok.Getter;
import lombok.NonNull;
import lombok.RequiredArgsConstructor;
import lombok.ToString;

import java.util.Objects;

/**
 * Schema name and table name.
 */
@RequiredArgsConstructor
@Getter
@ToString
public class SchemaTableName {
    
    @NonNull
    private final SchemaName schemaName;
    
    @NonNull
    private final TableName tableName;
    
    @Override
    public boolean equals(final Object o) {
        if (this == o) {
            return true;
        }
        if (null == o || getClass() != o.getClass()) {
            return false;
        }
        final SchemaTableName that = (SchemaTableName) o;
        return schemaName.equals(that.schemaName) && tableName.equals(that.tableName);
    }
    
    @Override
    public int hashCode() {
        return Objects.hash(schemaName, tableName);
    }
}

==> shardingsphere-data-pipeline-api-5.4.1-sources.jar: org/apache/shardingsphere/data/pipeline/api/metadata/SchemaTableName.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.data.pipeline.api.metadata;

import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.NonNull;
import lombok.RequiredArgsConstructor;
import lombok.ToString;

/**
 * Schema name and table name.
 */
@RequiredArgsConstructor
@Getter
@EqualsAndHashCode
@ToString
public class SchemaTableName {
    
    @NonNull
    private final SchemaName schemaName;
    
    @NonNull
    private final TableName tableName;
    
    public SchemaTableName(final String schemaName, final String tableName) {
        this.schemaName = new SchemaName(schemaName);
        this.tableName = new TableName(tableName);
    }
    
    /**
     * Marshal to text.
     *
     * @return text
     */
    public String marshal() {
        String schemaName = this.schemaName.getOriginal();
        return null == schemaName ? tableName.getOriginal() : schemaName + "." + tableName.getOriginal();
    }
}
